/* SQLHeavyGTK.h generated by valac 0.16.0, the Vala compiler, do not modify */


#ifndef __SQLHEAVYGTK_H__
#define __SQLHEAVYGTK_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <SQLHeavy.h>

G_BEGIN_DECLS


#define SQL_HEAVY_GTK_TYPE_MODEL (sql_heavy_gtk_model_get_type ())
#define SQL_HEAVY_GTK_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SQL_HEAVY_GTK_TYPE_MODEL, SQLHeavyGtkModel))
#define SQL_HEAVY_GTK_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SQL_HEAVY_GTK_TYPE_MODEL, SQLHeavyGtkModelClass))
#define SQL_HEAVY_GTK_IS_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SQL_HEAVY_GTK_TYPE_MODEL))
#define SQL_HEAVY_GTK_IS_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SQL_HEAVY_GTK_TYPE_MODEL))
#define SQL_HEAVY_GTK_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SQL_HEAVY_GTK_TYPE_MODEL, SQLHeavyGtkModelClass))

typedef struct _SQLHeavyGtkModel SQLHeavyGtkModel;
typedef struct _SQLHeavyGtkModelClass SQLHeavyGtkModelClass;
typedef struct _SQLHeavyGtkModelPrivate SQLHeavyGtkModelPrivate;

struct _SQLHeavyGtkModel {
	GObject parent_instance;
	SQLHeavyGtkModelPrivate * priv;
};

struct _SQLHeavyGtkModelClass {
	GObjectClass parent_class;
	void (*ref_node) (SQLHeavyGtkModel* self, GtkTreeIter* iter);
	void (*unref_node) (SQLHeavyGtkModel* self, GtkTreeIter* iter);
};


GType sql_heavy_gtk_model_get_type (void) G_GNUC_CONST;
void sql_heavy_gtk_model_ref_node (SQLHeavyGtkModel* self, GtkTreeIter* iter);
void sql_heavy_gtk_model_unref_node (SQLHeavyGtkModel* self, GtkTreeIter* iter);
SQLHeavyGtkModel* sql_heavy_gtk_model_new (SQLHeavyTable* table);
SQLHeavyGtkModel* sql_heavy_gtk_model_construct (GType object_type, SQLHeavyTable* table);
SQLHeavyTable* sql_heavy_gtk_model_get_table (SQLHeavyGtkModel* self);


G_END_DECLS

#endif
